@@ -4,8 +4,9 @@ from textwrap import dedent
 import pytest
 from lxml.etree import Element, tostring as etree_tostring
 
-from streamlink.exceptions import PluginError, StreamlinkDeprecationWarning
+from streamlink.exceptions import PluginError
 from streamlink.plugin.api import validate
+
 # noinspection PyProtectedMember
 from streamlink.plugin.api.validate._exception import ValidationError
 
@@ -14,18 +15,6 @@ def assert_validationerror(exception, expected):
     assert str(exception) == dedent(expected).strip("\n")
 
 
-def test_text_is_str(recwarn: pytest.WarningsRecorder):
-    assert "text" not in getattr(validate, "__dict__")
-    assert "text" in getattr(validate, "__all__")
-    assert validate.text is str, "Exports text as str alias for backwards compatiblity"
-    assert [(record.category, str(record.message)) for record in recwarn.list] == [
-        (
-            StreamlinkDeprecationWarning,
-            "`streamlink.plugin.api.validate.text` is deprecated. Use `str` instead.",
-        ),
-    ]
-
-
 class TestSchema:
     @pytest.fixture(scope="class")
     def schema(self):
@@ -107,7 +96,7 @@ class TestType:
 
 class TestSequence:
     @pytest.mark.parametrize(
-        "schema, value",
+        ("schema", "value"),
         [
             ([3, 2, 1, 0], [1, 2]),
             ((3, 2, 1, 0), (1, 2)),
@@ -160,7 +149,7 @@ class TestDict:
         assert result is not value
 
     @pytest.mark.parametrize(
-        "value, expected",
+        ("value", "expected"),
         [
             ({"foo": "foo"}, {"foo": "foo"}),
             ({"bar": "bar"}, {}),
@@ -168,13 +157,13 @@ class TestDict:
         ids=[
             "existing",
             "missing",
-        ]
+        ],
     )
     def test_optional(self, value, expected):
         assert validate.validate({validate.optional("foo"): "foo"}, value) == expected
 
     @pytest.mark.parametrize(
-        "schema, value, expected",
+        ("schema", "value", "expected"),
         [
             (
                 {str: {int: str}},
@@ -279,7 +268,7 @@ class TestCallable:
 
 
 class TestPattern:
-    @pytest.mark.parametrize("pattern,data,expected", [
+    @pytest.mark.parametrize(("pattern", "data", "expected"), [
         (r"\s(?P<bar>\S+)\s", "foo bar baz", {"bar": "bar"}),
         (rb"\s(?P<bar>\S+)\s", b"foo bar baz", {"bar": b"bar"}),
     ])
@@ -331,35 +320,35 @@ class TestAllSchema:
         assert validate.validate(schema, "foo") == "foo"
 
     @pytest.mark.parametrize(
-        "value, error",
+        ("value", "error"),
         [
             (
                 123,
                 """
                     ValidationError(type):
                       Type of 123 should be str, but is int
-                """
+                """,
             ),
             (
                 "bar",
                 """
                     ValidationError(Callable):
                       <lambda>('bar') is not true
-                """
+                """,
             ),
             (
                 "failure",
                 """
                     ValidationError(equality):
                       'failure' does not equal 'foo'
-                """
+                """,
             ),
         ],
         ids=[
             "first",
             "second",
             "third",
-        ]
+        ],
     )
     def test_failure(self, schema, value, error):
         with pytest.raises(ValidationError) as cm:
@@ -387,7 +376,7 @@ class TestAnySchema:
             "first",
             "second",
             "third",
-        ]
+        ],
     )
     def test_success(self, schema, value):
         assert validate.validate(schema, value) is value
@@ -407,7 +396,7 @@ class TestAnySchema:
 
 
 class TestNoneOrAllSchema:
-    @pytest.mark.parametrize("data,expected", [("foo", "FOO"), ("bar", None)])
+    @pytest.mark.parametrize(("data", "expected"), [("foo", "FOO"), ("bar", None)])
     def test_success(self, data, expected):
         assert validate.validate(
             validate.Schema(
@@ -483,7 +472,7 @@ class TestListSchema:
 
 
 class TestRegexSchema:
-    @pytest.mark.parametrize("pattern,data,expected", [
+    @pytest.mark.parametrize(("pattern", "data", "expected"), [
         (r"\s(?P<bar>\S+)\s", "foo bar baz", {"bar": "bar"}),
         (rb"\s(?P<bar>\S+)\s", b"foo bar baz", {"bar": b"bar"}),
     ])
@@ -626,7 +615,7 @@ class TestGetItemSchema:
     def test_strict(self):
         dictionary = {
             ("foo", "bar", "baz"): "foo-bar-baz",
-            "foo": {"bar": {"baz": "qux"}}
+            "foo": {"bar": {"baz": "qux"}},
         }
         assert validate.validate(validate.get(("foo", "bar", "baz"), strict=True), dictionary) == "foo-bar-baz"
 
@@ -639,11 +628,11 @@ class TestAttrSchema:
         def __repr__(self):
             return self.__class__.__name__
 
-    @pytest.fixture(scope="function")
+    @pytest.fixture()
     def obj(self):
         obj1 = self.Subject()
         obj2 = self.Subject()
-        setattr(obj1, "bar", obj2)
+        obj1.bar = obj2
 
         return obj1
 
@@ -677,7 +666,7 @@ class TestAttrSchema:
 class TestXmlElementSchema:
     upper = validate.transform(str.upper)
 
-    @pytest.fixture(scope="function")
+    @pytest.fixture()
     def element(self):
         childA = Element("childA", {"a": "1"})
         childB = Element("childB", {"b": "2"})
@@ -697,32 +686,32 @@ class TestXmlElementSchema:
         return parent
 
     @pytest.mark.parametrize(
-        "schema, expected",
+        ("schema", "expected"),
         [
             (
                 validate.xml_element(),
                 (
                     "<parent attrkey1=\"attrval1\" attrkey2=\"attrval2\">"
-                    "parenttext"
-                    "<childA a=\"1\">childAtext</childA>"
-                    "childAtail"
-                    "<childB b=\"2\">childBtext<childC/></childB>"
-                    "childBtail"
-                    "</parent>"
-                    "parenttail"
+                    + "parenttext"
+                    + "<childA a=\"1\">childAtext</childA>"
+                    + "childAtail"
+                    + "<childB b=\"2\">childBtext<childC/></childB>"
+                    + "childBtail"
+                    + "</parent>"
+                    + "parenttail"
                 ),
             ),
             (
                 validate.xml_element(tag=upper, attrib={upper: upper}, text=upper, tail=upper),
                 (
                     "<PARENT ATTRKEY1=\"ATTRVAL1\" ATTRKEY2=\"ATTRVAL2\">"
-                    "PARENTTEXT"
-                    "<childA a=\"1\">childAtext</childA>"
-                    "childAtail"
-                    "<childB b=\"2\">childBtext<childC/></childB>"
-                    "childBtail"
-                    "</PARENT>"
-                    "PARENTTAIL"
+                    + "PARENTTEXT"
+                    + "<childA a=\"1\">childAtext</childA>"
+                    + "childAtail"
+                    + "<childB b=\"2\">childBtext<childC/></childB>"
+                    + "childBtail"
+                    + "</PARENT>"
+                    + "PARENTTAIL"
                 ),
             ),
         ],
@@ -740,7 +729,7 @@ class TestXmlElementSchema:
         assert newelement[1][0] is not element[1][0]
 
     @pytest.mark.parametrize(
-        "schema, error",
+        ("schema", "error"),
         [
             (
                 validate.xml_element(tag="invalid"),
@@ -784,7 +773,7 @@ class TestXmlElementSchema:
             "attrib",
             "text",
             "tail",
-        ]
+        ],
     )
     def test_failure(self, element, schema, error):
         with pytest.raises(ValidationError) as cm:
@@ -847,7 +836,7 @@ class TestUnionSchema:
         """)
 
     @pytest.mark.parametrize(
-        "schema, expected",
+        ("schema", "expected"),
         [
             (validate.union([str, upper]), ["value", "VALUE"]),
             (validate.union((str, upper)), ("value", "VALUE")),
@@ -878,15 +867,15 @@ class TestUnionSchema:
 
 class TestLengthValidator:
     @pytest.mark.parametrize(
-        "minlength, value",
-        [(3, "foo"), (3, [1, 2, 3])]
+        ("minlength", "value"),
+        [(3, "foo"), (3, [1, 2, 3])],
     )
     def test_success(self, minlength, value):
         assert validate.validate(validate.length(minlength), value)
 
     @pytest.mark.parametrize(
-        "minlength, value",
-        [(3, "foo"), (3, [1, 2, 3])]
+        ("minlength", "value"),
+        [(3, "foo"), (3, [1, 2, 3])],
     )
     def test_failure(self, minlength, value):
         with pytest.raises(ValidationError) as cm:
@@ -1042,7 +1031,7 @@ class TestHasAttrValidator:
         def __repr__(self):
             return self.__class__.__name__
 
-    def test_success(self,):
+    def test_success(self):
         assert validate.validate(validate.hasattr("foo"), self.Subject())
 
     def test_failure(self):
@@ -1424,13 +1413,13 @@ class TestValidationError:
         err = ValidationError(
             ValidationError(
                 "foo",
-                schema=dict
+                schema=dict,
             ),
             ValidationError(
                 "bar",
-                schema="something"
+                schema="something",
             ),
-            schema=validate.any
+            schema=validate.any,
         )
         assert_validationerror(err, """
             ValidationError(AnySchema):
@@ -1463,4 +1452,4 @@ class TestValidationError:
         assert_validationerror(err, """
             ValidationError:
               foo <Some really long error message that exceeds the maximum...> bar <'Some really long error message that exceeds the maximu...> baz
-        """)  # noqa: 501
+        """)  # noqa: E501
